summaryrefslogtreecommitdiff
path: root/indra/llxuixml/llinitparam.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/llxuixml/llinitparam.cpp')
-rw-r--r--indra/llxuixml/llinitparam.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/llxuixml/llinitparam.cpp b/indra/llxuixml/llinitparam.cpp
index bf2de9360a..fcdbaa4309 100644
--- a/indra/llxuixml/llinitparam.cpp
+++ b/indra/llxuixml/llinitparam.cpp
@@ -313,10 +313,10 @@ namespace LLInitParam
}
// if no match, and no names left on stack, this is just an existence assertion of this block
// verify by calling readValue with NoValue type, an inherently unparseable type
if (!names_left)
{
- NoValue no_value;
+ NoParamValue no_value;
return p.readValue(no_value);
}
@@ -313,10 +313,10 @@ namespace LLInitParam
}
// if no match, and no names left on stack, this is just an existence assertion of this block
- // verify by calling readValue with NoValue type, an inherently unparseable type
+ // verify by calling readValue with NoParamValue type, an inherently unparseable type
if (!names_left)
{